Required ENV Settings/Vars
~~~~~~~~~~~~~~~~~~~~~~~~~~

`START_DATE` defaults to `2019-06-01`

`END_DATE` defaults to `2019-08-01`

`REPORT_MONTHS` defaults to `2`

`DYNAMIC_DATES` defaults to `null` determine whether to use the above dates or use today's date minus REPORT_MONTHS

RedShift
========

- `REDSHIFT_PWD` 

- `REDSHIFT_DSN` 

- `REDSHIFT_USR`


Facebook
========

- `FACEBOOK_APP_ID`

- `FACEBOOK_ACCESS_TOKEN`

- `FACEBOOK_APP_SECRET`

- `FACEBOOK_APP_TOKEN`

- `FACEBOOK_PG_TOKEN`

- `FACEBOOK_LONG_ACCESS_TOKEN`


Chaa jaa Facebook
=================

- `AD_ACCOUNT_ACCOUNTID`

- `AD_ACCOUNT_ACCOUNTNAME`


- `CHAA_JAA_ACCOUNTID`

- `CHAA_JAA_ACCOUNTNAME`

- `CHAA_JAA_CAMPAIGNID`

- `CHAA_JAA_CAMPAIGNNAME`


- `CHAA_JAA_PAGEID`

- `CHAA_JAA_FACEBOOKPAGENAME`

- `CHAA_JAA_GEPAGENAME`

- `CHAA_JAA_PAGEAPP`

- `CHAA_JAA_ACCESS_TOKEN`


Chaa jaaa YT
============

- `YT_CLIENT_ID`

- `YT_CLIENT_SECRET`

- `YT_PROJECT_ID`

- `YT_CHANNEL`

- `YT_PLAYLIST`


Obtained from the youtube .dat file

- `YOUTUBE_ACCESS_TOKEN`

- `YOUTUBE_CLIENT_ID`

- `YOUTUBE_CLIENT_SECRET`

- `YOUTUBE_REFRESH_TOKEN`

- `YOUTUBE_TOKEN_EXPIRY`

- `YOUTUBE_TOKEN_RESPONSE_ACCESS_TOKEN`


Obtained from the YTanalytics .dat file

`YT_ANALYTICS_ACCESS_TOKEN`

`YT_ANALYTICS_CLIENT_ID`

`YT_ANALYTICS_CLIENT_SECRET`

`YT_ANALYTICS_REFRESH_TOKEN`

`YT_ANALYTICS_TOKEN_EXPIRY`

`YT_ANALYTICS_RESPONSE_ACCESS_TOKEN`

`YT_ANALYTICS_RESPONSE_REFRESH_TOKEN`


Chaa jaaa GA
============

- `CHAAJAAUSER_VIEW`

- `CHAAJAAUSER_VIEWID`
